[API Reference](../README.md) > [ArcTransactionProposalResult](../classes/ArcTransactionProposalResult.md)

# Class: ArcTransactionProposalResult

Base or actual type returned by all contract wrapper methods that generate a transaction and initiate a proposal.

## Hierarchy

 [ArcTransactionResult](ArcTransactionResult.md)

**↳ ArcTransactionProposalResult**

## Index

### Constructors

* [constructor](ArcTransactionProposalResult.md#constructor)

### Properties

* [tx](ArcTransactionProposalResult.md#tx)
* [votingMachine](ArcTransactionProposalResult.md#votingMachine)

### Methods

* [getProposalIdFromMinedTx](ArcTransactionProposalResult.md#getProposalIdFromMinedTx)
* [getTxConfirmed](ArcTransactionProposalResult.md#getTxConfirmed)
* [getTxMined](ArcTransactionProposalResult.md#getTxMined)
* [getValueFromMinedTx](ArcTransactionProposalResult.md#getValueFromMinedTx)
* [watchForTxConfirmed](ArcTransactionProposalResult.md#watchForTxConfirmed)
* [watchForTxMined](ArcTransactionProposalResult.md#watchForTxMined)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new ArcTransactionProposalResult**(tx: *[Hash](../#Hash)*, contract: *`any`*, votingMachine: *[IIntVoteInterface](../interfaces/IIntVoteInterface.md)*): [ArcTransactionProposalResult](ArcTransactionProposalResult.md)

*Overrides [ArcTransactionResult](ArcTransactionResult.md).[constructor](ArcTransactionResult.md#constructor)*

*Defined in [iContractWrapperBase.ts:153](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L153)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| tx | [Hash](../#Hash) |
| contract | `any` |
| votingMachine | [IIntVoteInterface](../interfaces/IIntVoteInterface.md) |

**Returns:** [ArcTransactionProposalResult](ArcTransactionProposalResult.md)

___

## Properties

<a id="tx"></a>

###  tx

**● tx**: *[Hash](../#Hash)*

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[tx](ArcTransactionResult.md#tx)*

*Defined in [iContractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L61)*

The transaction hash

___
<a id="votingMachine"></a>

###  votingMachine

**● votingMachine**: *[IIntVoteInterface](../interfaces/IIntVoteInterface.md)*

*Defined in [iContractWrapperBase.ts:161](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L161)*

The proposal's voting machine, as IntVoteInterface

___

## Methods

<a id="getProposalIdFromMinedTx"></a>

###  getProposalIdFromMinedTx

▸ **getProposalIdFromMinedTx**(): `Promise`<[Hash](../#Hash)>

*Defined in [iContractWrapperBase.ts:170](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L170)*

Returns promise of the proposal id from the logs of the mined transaction. Will watch for the mined tx; if it hasn't yet been mined, could take a while to return.

**Returns:** `Promise`<[Hash](../#Hash)>

___
<a id="getTxConfirmed"></a>

###  getTxConfirmed

▸ **getTxConfirmed**(requiredDepth?: *`number`*): `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[getTxConfirmed](ArcTransactionResult.md#getTxConfirmed)*

*Defined in [iContractWrapperBase.ts:92](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L92)*

Returns a promise of the transaction if it is confirmed, converted to a TransactionReceiptTruffle (with readable logs).

Returns null if the transaction is not yet found at the required depth.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| `Optional` requiredDepth | `number` |  Optional minimum block depth required to resolve the promise. Default comes from the \`ConfigService\`. |

**Returns:** `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

___
<a id="getTxMined"></a>

###  getTxMined

▸ **getTxMined**(): `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[getTxMined](ArcTransactionResult.md#getTxMined)*

*Defined in [iContractWrapperBase.ts:74](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L74)*

Returns a promise of the transaction if it is mined, converted to a TransactionReceiptTruffle (with readable logs).

Returns null if the transaciton is not yet mined.

**Returns:** `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

___
<a id="getValueFromMinedTx"></a>

###  getValueFromMinedTx

▸ **getValueFromMinedTx**(valueName: *`string`*, eventName?: *`string`*, index?: *`number`*): `Promise`< `any` &#124; `undefined`>

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[getValueFromMinedTx](ArcTransactionResult.md#getValueFromMinedTx)*

*Defined in [iContractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L140)*

Returns promise of a value from the logs of the mined transaction. Will watch for the mined tx, so could take a while to return.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| valueName | `string` | - |  The name of the property whose value we wish to return |
| `Default value` eventName | `string` |  null |  Name of the event in whose log we are to look for the value |
| `Default value` index | `number` | 0 |  Index of the log in which to look for the value, when eventName is not given. Default is the index of the last log in the transaction. |

**Returns:** `Promise`< `any` &#124; `undefined`>

___
<a id="watchForTxConfirmed"></a>

###  watchForTxConfirmed

▸ **watchForTxConfirmed**(requiredDepth?: *`number`*): `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[watchForTxConfirmed](ArcTransactionResult.md#watchForTxConfirmed)*

*Defined in [iContractWrapperBase.ts:123](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L123)*

Returns a promise of a TransactionReceipt once the given transaction has been confirmed, converted to a TransactionReceiptTruffle (with readable logs), according to the optional `requiredDepth`.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| `Optional` requiredDepth | `number` |  Optional minimum block depth required to resolve the promise. Default comes from the \`ConfigService\`. |

**Returns:** `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

___
<a id="watchForTxMined"></a>

###  watchForTxMined

▸ **watchForTxMined**(): `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

*Inherited from [ArcTransactionResult](ArcTransactionResult.md).[watchForTxMined](ArcTransactionResult.md#watchForTxMined)*

*Defined in [iContractWrapperBase.ts:106](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L106)*

Returns promise of a mined transaction once it has been mined, converted to a TransactionReceiptTruffle (with readable logs).

**Returns:** `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

___

