[API Reference](../README.md) > [ArcTransactionResult](../classes/ArcTransactionResult.md)

# Class: ArcTransactionResult

## Hierarchy

**ArcTransactionResult**

↳  [ArcTransactionProposalResult](ArcTransactionProposalResult.md)

↳  [ArcTransactionDataResult](ArcTransactionDataResult.md)

↳  [ArcTransactionAgreementResult](ArcTransactionAgreementResult.md)

## Index

### Constructors

* [constructor](ArcTransactionResult.md#constructor)

### Properties

* [tx](ArcTransactionResult.md#tx)

### Methods

* [getTxConfirmed](ArcTransactionResult.md#getTxConfirmed)
* [getTxMined](ArcTransactionResult.md#getTxMined)
* [getValueFromMinedTx](ArcTransactionResult.md#getValueFromMinedTx)
* [watchForTxConfirmed](ArcTransactionResult.md#watchForTxConfirmed)
* [watchForTxMined](ArcTransactionResult.md#watchForTxMined)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new ArcTransactionResult**(tx: *[Hash](../#Hash)*, contract: * `string` &#124; `any`*): [ArcTransactionResult](ArcTransactionResult.md)

*Defined in [iContractWrapperBase.ts:55](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L55)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| tx | [Hash](../#Hash) |
| contract |  `string` &#124; `any`|

**Returns:** [ArcTransactionResult](ArcTransactionResult.md)

___

## Properties

<a id="tx"></a>

###  tx

**● tx**: *[Hash](../#Hash)*

*Defined in [iContractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L61)*

The transaction hash

___

## Methods

<a id="getTxConfirmed"></a>

###  getTxConfirmed

▸ **getTxConfirmed**(requiredDepth?: *`number`*): `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

*Defined in [iContractWrapperBase.ts:92](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L92)*

Returns a promise of the transaction if it is confirmed, converted to a TransactionReceiptTruffle (with readable logs).

Returns null if the transaction is not yet found at the required depth.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| `Optional` requiredDepth | `number` |  Optional minimum block depth required to resolve the promise. Default comes from the \`ConfigService\`. |

**Returns:** `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

___
<a id="getTxMined"></a>

###  getTxMined

▸ **getTxMined**(): `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

*Defined in [iContractWrapperBase.ts:74](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L74)*

Returns a promise of the transaction if it is mined, converted to a TransactionReceiptTruffle (with readable logs).

Returns null if the transaciton is not yet mined.

**Returns:** `Promise`< [TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md) &#124; `null`>

___
<a id="getValueFromMinedTx"></a>

###  getValueFromMinedTx

▸ **getValueFromMinedTx**(valueName: *`string`*, eventName?: *`string`*, index?: *`number`*): `Promise`< `any` &#124; `undefined`>

*Defined in [iContractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L140)*

Returns promise of a value from the logs of the mined transaction. Will watch for the mined tx, so could take a while to return.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| valueName | `string` | - |  The name of the property whose value we wish to return |
| `Default value` eventName | `string` |  null |  Name of the event in whose log we are to look for the value |
| `Default value` index | `number` | 0 |  Index of the log in which to look for the value, when eventName is not given. Default is the index of the last log in the transaction. |

**Returns:** `Promise`< `any` &#124; `undefined`>

___
<a id="watchForTxConfirmed"></a>

###  watchForTxConfirmed

▸ **watchForTxConfirmed**(requiredDepth?: *`number`*): `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

*Defined in [iContractWrapperBase.ts:123](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L123)*

Returns a promise of a TransactionReceipt once the given transaction has been confirmed, converted to a TransactionReceiptTruffle (with readable logs), according to the optional `requiredDepth`.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| `Optional` requiredDepth | `number` |  Optional minimum block depth required to resolve the promise. Default comes from the \`ConfigService\`. |

**Returns:** `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

___
<a id="watchForTxMined"></a>

###  watchForTxMined

▸ **watchForTxMined**(): `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

*Defined in [iContractWrapperBase.ts:106](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L106)*

Returns promise of a mined transaction once it has been mined, converted to a TransactionReceiptTruffle (with readable logs).

**Returns:** `Promise`<[TransactionReceiptTruffle](../interfaces/TransactionReceiptTruffle.md)>

___

