[API Reference](../README.md) > [ContractWrapperBase](../classes/ContractWrapperBase.md)

# Class: ContractWrapperBase

Abstract base class for all Arc contract wrapper classes.

Example of how to define a wrapper:

```
import { ContractWrapperBase } from "../contractWrapperBase";
import { ContractWrapperFactory } from "../contractWrapperFactory";

export class AbsoluteVoteWrapper extends ContractWrapperBase {
  [ wrapper properties and methods ]
}

export const AbsoluteVote = new ContractWrapperFactory(
 "AbsoluteVote",
 AbsoluteVoteWrapper,
 new Web3EventService());

```

## Hierarchy

**ContractWrapperBase**

↳  [StandardTokenWrapper](StandardTokenWrapper.md)

↳  [ReputationWrapper](ReputationWrapper.md)

↳  [IntVoteInterfaceWrapper](IntVoteInterfaceWrapper.md)

↳  [SchemeWrapperBase](SchemeWrapperBase.md)

↳  [RedeemerWrapper](RedeemerWrapper.md)

↳  [TokenCapGCWrapper](TokenCapGCWrapper.md)

↳  [DaoCreatorWrapper](DaoCreatorWrapper.md)

## Implements

* [IContractWrapper](../interfaces/IContractWrapper.md)

## Index

### Constructors

* [constructor](ContractWrapperBase.md#constructor)

### Properties

* [contract](ContractWrapperBase.md#contract)
* [factory](ContractWrapperBase.md#factory)
* [friendlyName](ContractWrapperBase.md#friendlyName)
* [name](ContractWrapperBase.md#name)

### Accessors

* [address](ContractWrapperBase.md#address)

### Methods

* [estimateGas](ContractWrapperBase.md#estimateGas)
* [getParameters](ContractWrapperBase.md#getParameters)
* [getParametersArray](ContractWrapperBase.md#getParametersArray)
* [hydrateFromAt](ContractWrapperBase.md#hydrateFromAt)
* [hydrateFromNew](ContractWrapperBase.md#hydrateFromNew)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new ContractWrapperBase**(solidityContract: *`any`*, web3EventService: *[Web3EventService](Web3EventService.md)*): [ContractWrapperBase](ContractWrapperBase.md)

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

ContractWrapperFactory constructs this

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| solidityContract | `any` |  The json contract truffle artifact |
| web3EventService | [Web3EventService](Web3EventService.md) |   |

**Returns:** [ContractWrapperBase](ContractWrapperBase.md)

___

## Properties

<a id="contract"></a>

###  contract

**● contract**: *`any`*

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[contract](../interfaces/IContractWrapper.md#contract)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

The underlying truffle contract object. Use this to access parts of the contract that aren't accessible via the wrapper.

___
<a id="factory"></a>

### `<Abstract>` factory

**● factory**: *[IContractWrapperFactory](../interfaces/IContractWrapperFactory.md)<`any`>*

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[factory](../interfaces/IContractWrapper.md#factory)*

*Defined in [contractWrapperBase.ts:49](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L49)*

The wrapper factor class providing static methods `at(someAddress)`, `new()` and `deployed()`.

___
<a id="friendlyName"></a>

### `<Abstract>` friendlyName

**● friendlyName**: *`string`*

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[friendlyName](../interfaces/IContractWrapper.md#friendlyName)*

*Defined in [contractWrapperBase.ts:57](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L57)*

A more friendly name for the contract.

___
<a id="name"></a>

### `<Abstract>` name

**● name**: *`string`*

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[name](../interfaces/IContractWrapper.md#name)*

*Defined in [contractWrapperBase.ts:53](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L53)*

The name of the contract.

___

## Accessors

<a id="address"></a>

###  address

getaddress(): [Address](../#Address)

*Defined in [contractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L61)*

The address of the contract

**Returns:** [Address](../#Address)

___

## Methods

<a id="estimateGas"></a>

###  estimateGas

▸ **estimateGas**(func: *[ITruffleContractFunction](../interfaces/ITruffleContractFunction.md)*, params: *`Array`<`any`>*, web3Params?: *`any`*): `Promise`<`number`>

*Defined in [contractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L140)*

Estimate conservatively the amount of gas required to execute the given function with the given parameters. Adds 21000 to the estimate computed by web3.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| func | [ITruffleContractFunction](../interfaces/ITruffleContractFunction.md) | - |  The function |
| params | `Array`<`any`> | - |  The parameters to send to the function |
| `Default value` web3Params | `any` |  {} |  The web3 parameters (like "from", for example). If it contains "gas" then that value is returned, effectively a no-op. |

**Returns:** `Promise`<`number`>

___
<a id="getParameters"></a>

###  getParameters

▸ **getParameters**(paramsHash: *[Hash](../#Hash)*): `Promise`<`any`>

*Defined in [contractWrapperBase.ts:118](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L118)*

Given a hash, returns the associated parameters as an object.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`any`>

___
<a id="getParametersArray"></a>

###  getParametersArray

▸ **getParametersArray**(paramsHash: *[Hash](../#Hash)*): `Promise`<`Array`<`any`>>

*Defined in [contractWrapperBase.ts:127](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L127)*

Given a hash, returns the associated parameters as an array, ordered by the order in which the parameters appear in the contract's Parameters struct.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`Array`<`any`>>

___
<a id="hydrateFromAt"></a>

###  hydrateFromAt

▸ **hydrateFromAt**(address: *`string`*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[hydrateFromAt](../interfaces/IContractWrapper.md#hydrateFromAt)*

*Defined in [contractWrapperBase.ts:100](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L100)*

Initialize from a given address on the current network.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| address | `string` |  of the deployed contract |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this or undefined if not found

___
<a id="hydrateFromNew"></a>

###  hydrateFromNew

▸ **hydrateFromNew**(...rest: *`Array`<`any`>*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[hydrateFromNew](../interfaces/IContractWrapper.md#hydrateFromNew)*

*Defined in [contractWrapperBase.ts:81](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L81)*

Initialize from a newly-migrated instance. This will migrate a new instance of the contract to the net.

**Parameters:**

| Param | Type |
| ------ | ------ |
| `Rest` rest | `Array`<`any`> |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this

___

