[API Reference](../README.md) > [IntVoteInterfaceWrapper](../classes/IntVoteInterfaceWrapper.md)

# Class: IntVoteInterfaceWrapper

Provides the services of any voting machine that implements the `IntVoteInterface` Arc contract interface. Also serves as the base class for all the specific voting machine contract wrapper classes.

## Hierarchy

 [ContractWrapperBase](ContractWrapperBase.md)

**↳ IntVoteInterfaceWrapper**

↳  [AbsoluteVoteWrapper](AbsoluteVoteWrapper.md)

↳  [GenesisProtocolWrapper](GenesisProtocolWrapper.md)

## Implements

* [IContractWrapper](../interfaces/IContractWrapper.md)
* [IIntVoteInterface](../interfaces/IIntVoteInterface.md)

## Index

### Constructors

* [constructor](IntVoteInterfaceWrapper.md#constructor)

### Properties

* [CancelProposal](IntVoteInterfaceWrapper.md#CancelProposal)
* [CancelVoting](IntVoteInterfaceWrapper.md#CancelVoting)
* [ExecuteProposal](IntVoteInterfaceWrapper.md#ExecuteProposal)
* [NewProposal](IntVoteInterfaceWrapper.md#NewProposal)
* [VoteProposal](IntVoteInterfaceWrapper.md#VoteProposal)
* [contract](IntVoteInterfaceWrapper.md#contract)
* [factory](IntVoteInterfaceWrapper.md#factory)
* [friendlyName](IntVoteInterfaceWrapper.md#friendlyName)
* [name](IntVoteInterfaceWrapper.md#name)

### Accessors

* [VotableProposals](IntVoteInterfaceWrapper.md#VotableProposals)
* [address](IntVoteInterfaceWrapper.md#address)

### Methods

* [cancelProposal](IntVoteInterfaceWrapper.md#cancelProposal)
* [cancelVote](IntVoteInterfaceWrapper.md#cancelVote)
* [estimateGas](IntVoteInterfaceWrapper.md#estimateGas)
* [execute](IntVoteInterfaceWrapper.md#execute)
* [getAllowedRangeOfChoices](IntVoteInterfaceWrapper.md#getAllowedRangeOfChoices)
* [getCurrentVoteStatus](IntVoteInterfaceWrapper.md#getCurrentVoteStatus)
* [getNumberOfChoices](IntVoteInterfaceWrapper.md#getNumberOfChoices)
* [getParameters](IntVoteInterfaceWrapper.md#getParameters)
* [getParametersArray](IntVoteInterfaceWrapper.md#getParametersArray)
* [hydrateFromAt](IntVoteInterfaceWrapper.md#hydrateFromAt)
* [hydrateFromNew](IntVoteInterfaceWrapper.md#hydrateFromNew)
* [isAbstainAllow](IntVoteInterfaceWrapper.md#isAbstainAllow)
* [isVotable](IntVoteInterfaceWrapper.md#isVotable)
* [ownerVote](IntVoteInterfaceWrapper.md#ownerVote)
* [propose](IntVoteInterfaceWrapper.md#propose)
* [vote](IntVoteInterfaceWrapper.md#vote)
* [voteStatus](IntVoteInterfaceWrapper.md#voteStatus)
* [voteWithSpecifiedAmounts](IntVoteInterfaceWrapper.md#voteWithSpecifiedAmounts)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new IntVoteInterfaceWrapper**(solidityContract: *`any`*, web3EventService: *[Web3EventService](Web3EventService.md)*): [IntVoteInterfaceWrapper](IntVoteInterfaceWrapper.md)

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[constructor](ContractWrapperBase.md#constructor)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

ContractWrapperFactory constructs this

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| solidityContract | `any` |  The json contract truffle artifact |
| web3EventService | [Web3EventService](Web3EventService.md) |   |

**Returns:** [IntVoteInterfaceWrapper](IntVoteInterfaceWrapper.md)

___

## Properties

<a id="CancelProposal"></a>

###  CancelProposal

**● CancelProposal**: *[EventFetcherFactory](../#EventFetcherFactory)<[CancelProposalEventResult](../interfaces/CancelProposalEventResult.md)>*

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[CancelProposal](../interfaces/IIntVoteInterface.md#CancelProposal)*

*Defined in [wrappers/intVoteInterface.ts:50](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L50)*

Get or watch events fired when a vote is cancelled. Note you won't get this from GenesisProtocol whose proposals and votes are not cancellable

___
<a id="CancelVoting"></a>

###  CancelVoting

**● CancelVoting**: *[EventFetcherFactory](../#EventFetcherFactory)<[CancelVotingEventResult](../interfaces/CancelVotingEventResult.md)>*

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[CancelVoting](../interfaces/IIntVoteInterface.md#CancelVoting)*

*Defined in [wrappers/intVoteInterface.ts:63](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L63)*

Get or watch events fired when a voter's vote is cancelled. Note you won't get this from GenesisProtocol whose proposals and votes are not cancellable

___
<a id="ExecuteProposal"></a>

###  ExecuteProposal

**● ExecuteProposal**: *[EventFetcherFactory](../#EventFetcherFactory)<[ExecuteProposalEventResult](../interfaces/ExecuteProposalEventResult.md)>*

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[ExecuteProposal](../interfaces/IIntVoteInterface.md#ExecuteProposal)*

*Defined in [wrappers/intVoteInterface.ts:54](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L54)*

Get or watch events fired when proposals have been executed

___
<a id="NewProposal"></a>

###  NewProposal

**● NewProposal**: *[EventFetcherFactory](../#EventFetcherFactory)<[NewProposalEventResult](../interfaces/NewProposalEventResult.md)>*

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[NewProposal](../interfaces/IIntVoteInterface.md#NewProposal)*

*Defined in [wrappers/intVoteInterface.ts:45](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L45)*

Get or watch events fired on the creation of a new proposal.

___
<a id="VoteProposal"></a>

###  VoteProposal

**● VoteProposal**: *[EventFetcherFactory](../#EventFetcherFactory)<[VoteProposalEventResult](../interfaces/VoteProposalEventResult.md)>*

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[VoteProposal](../interfaces/IIntVoteInterface.md#VoteProposal)*

*Defined in [wrappers/intVoteInterface.ts:58](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L58)*

Get or watch events fired whenever votes are cast on a proposal

___
<a id="contract"></a>

###  contract

**● contract**: *`any`*

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[contract](../interfaces/IContractWrapper.md#contract)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[contract](ContractWrapperBase.md#contract)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

The underlying truffle contract object. Use this to access parts of the contract that aren't accessible via the wrapper.

___
<a id="factory"></a>

###  factory

**● factory**: *[IContractWrapperFactory](../interfaces/IContractWrapperFactory.md)<`any`>* =  IntVoteInterfaceFactory

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[factory](../interfaces/IContractWrapper.md#factory)*

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[factory](ContractWrapperBase.md#factory)*

*Defined in [wrappers/intVoteInterface.ts:38](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L38)*

___
<a id="friendlyName"></a>

###  friendlyName

**● friendlyName**: *`string`* = "IntVoteInterface"

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[friendlyName](../interfaces/IContractWrapper.md#friendlyName)*

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[friendlyName](ContractWrapperBase.md#friendlyName)*

*Defined in [wrappers/intVoteInterface.ts:40](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L40)*

___
<a id="name"></a>

###  name

**● name**: *`string`* = "IntVoteInterface"

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[name](../interfaces/IContractWrapper.md#name)*

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[name](ContractWrapperBase.md#name)*

*Defined in [wrappers/intVoteInterface.ts:39](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L39)*

___

## Accessors

<a id="VotableProposals"></a>

###  VotableProposals

getVotableProposals(): [EventFetcherFactory](../#EventFetcherFactory)<[NewProposalEventResult](../interfaces/NewProposalEventResult.md)>

*Defined in [wrappers/intVoteInterface.ts:68](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L68)*

Get or watch NewProposal events, filtering out proposals that are no longer votable.

**Returns:** [EventFetcherFactory](../#EventFetcherFactory)<[NewProposalEventResult](../interfaces/NewProposalEventResult.md)>

___
<a id="address"></a>

###  address

getaddress(): [Address](../#Address)

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[address](ContractWrapperBase.md#address)*

*Defined in [contractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L61)*

The address of the contract

**Returns:** [Address](../#Address)

___

## Methods

<a id="cancelProposal"></a>

###  cancelProposal

▸ **cancelProposal**(options: * [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[cancelProposal](../interfaces/IIntVoteInterface.md#cancelProposal)*

*Defined in [wrappers/intVoteInterface.ts:131](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L131)*

Cancel the given proposal

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___
<a id="cancelVote"></a>

###  cancelVote

▸ **cancelVote**(options: * [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[cancelVote](../interfaces/IIntVoteInterface.md#cancelVote)*

*Defined in [wrappers/intVoteInterface.ts:220](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L220)*

Cancel voting on the proposal.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___
<a id="estimateGas"></a>

###  estimateGas

▸ **estimateGas**(func: *[ITruffleContractFunction](../interfaces/ITruffleContractFunction.md)*, params: *`Array`<`any`>*, web3Params?: *`any`*): `Promise`<`number`>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[estimateGas](ContractWrapperBase.md#estimateGas)*

*Defined in [contractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L140)*

Estimate conservatively the amount of gas required to execute the given function with the given parameters. Adds 21000 to the estimate computed by web3.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| func | [ITruffleContractFunction](../interfaces/ITruffleContractFunction.md) | - |  The function |
| params | `Array`<`any`> | - |  The parameters to send to the function |
| `Default value` web3Params | `any` |  {} |  The web3 parameters (like "from", for example). If it contains "gas" then that value is returned, effectively a no-op. |

**Returns:** `Promise`<`number`>

___
<a id="execute"></a>

###  execute

▸ **execute**(options: * [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[execute](../interfaces/IIntVoteInterface.md#execute)*

*Defined in [wrappers/intVoteInterface.ts:294](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L294)*

Attempt to execute the given proposal vote.

**Parameters:**

| Param | Type |
| ------ | ------ |
| options |  [ProposalIdOption](../interfaces/ProposalIdOption.md) & `TxGeneratingFunctionOptions`|

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___
<a id="getAllowedRangeOfChoices"></a>

###  getAllowedRangeOfChoices

▸ **getAllowedRangeOfChoices**(): `Promise`<[GetAllowedRangeOfChoicesResult](../interfaces/GetAllowedRangeOfChoicesResult.md)>

*Defined in [wrappers/intVoteInterface.ts:340](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L340)*

Returns promise of the allowed range of choices for a voting machine.

**Returns:** `Promise`<[GetAllowedRangeOfChoicesResult](../interfaces/GetAllowedRangeOfChoicesResult.md)>

___
<a id="getCurrentVoteStatus"></a>

###  getCurrentVoteStatus

▸ **getCurrentVoteStatus**(proposalId: *[Address](../#Address)*): `Promise`<`Array`<`BigNumber`>>

*Defined in [wrappers/intVoteInterface.ts:317](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L317)*

Return an array of the current counts of each vote choice on the proposal. For straight Abstain, Yes and No votes you can use the values of the `BinaryVoteResult` enum to dereference the array. The Abstain vote (in the zeroeth position) is always given even if the voting machine does not allow abstentions.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| proposalId | [Address](../#Address) |   |

**Returns:** `Promise`<`Array`<`BigNumber`>>

___
<a id="getNumberOfChoices"></a>

###  getNumberOfChoices

▸ **getNumberOfChoices**(options: *[ProposalIdOption](../interfaces/ProposalIdOption.md)*): `Promise`<`number`>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[getNumberOfChoices](../interfaces/IIntVoteInterface.md#getNumberOfChoices)*

*Defined in [wrappers/intVoteInterface.ts:238](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L238)*

Get the number of voting choices allowed by the proposal.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options | [ProposalIdOption](../interfaces/ProposalIdOption.md) |   |

**Returns:** `Promise`<`number`>

___
<a id="getParameters"></a>

###  getParameters

▸ **getParameters**(paramsHash: *[Hash](../#Hash)*): `Promise`<`any`>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[getParameters](ContractWrapperBase.md#getParameters)*

*Defined in [contractWrapperBase.ts:118](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L118)*

Given a hash, returns the associated parameters as an object.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`any`>

___
<a id="getParametersArray"></a>

###  getParametersArray

▸ **getParametersArray**(paramsHash: *[Hash](../#Hash)*): `Promise`<`Array`<`any`>>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[getParametersArray](ContractWrapperBase.md#getParametersArray)*

*Defined in [contractWrapperBase.ts:127](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L127)*

Given a hash, returns the associated parameters as an array, ordered by the order in which the parameters appear in the contract's Parameters struct.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`Array`<`any`>>

___
<a id="hydrateFromAt"></a>

###  hydrateFromAt

▸ **hydrateFromAt**(address: *`string`*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[hydrateFromAt](../interfaces/IContractWrapper.md#hydrateFromAt)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromAt](ContractWrapperBase.md#hydrateFromAt)*

*Defined in [contractWrapperBase.ts:100](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L100)*

Initialize from a given address on the current network.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| address | `string` |  of the deployed contract |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this or undefined if not found

___
<a id="hydrateFromNew"></a>

###  hydrateFromNew

▸ **hydrateFromNew**(...rest: *`Array`<`any`>*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [IContractWrapper](../interfaces/IContractWrapper.md).[hydrateFromNew](../interfaces/IContractWrapper.md#hydrateFromNew)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromNew](ContractWrapperBase.md#hydrateFromNew)*

*Defined in [contractWrapperBase.ts:81](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L81)*

Initialize from a newly-migrated instance. This will migrate a new instance of the contract to the net.

**Parameters:**

| Param | Type |
| ------ | ------ |
| `Rest` rest | `Array`<`any`> |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this

___
<a id="isAbstainAllow"></a>

###  isAbstainAllow

▸ **isAbstainAllow**(): `Promise`<`boolean`>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[isAbstainAllow](../interfaces/IIntVoteInterface.md#isAbstainAllow)*

*Defined in [wrappers/intVoteInterface.ts:282](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L282)*

get whether voters are allowed to cast an abstaining vote on these proposals.

**Returns:** `Promise`<`boolean`>

___
<a id="isVotable"></a>

###  isVotable

▸ **isVotable**(options: *[ProposalIdOption](../interfaces/ProposalIdOption.md)*): `Promise`<`boolean`>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[isVotable](../interfaces/IIntVoteInterface.md#isVotable)*

*Defined in [wrappers/intVoteInterface.ts:252](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L252)*

Get whether the proposal is in a state where it can be voted-upon.

**Parameters:**

| Param | Type |
| ------ | ------ |
| options | [ProposalIdOption](../interfaces/ProposalIdOption.md) |

**Returns:** `Promise`<`boolean`>

___
<a id="ownerVote"></a>

###  ownerVote

▸ **ownerVote**(options: * [OwnerVoteOptions](../interfaces/OwnerVoteOptions.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[ownerVote](../interfaces/IIntVoteInterface.md#ownerVote)*

*Defined in [wrappers/intVoteInterface.ts:149](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L149)*

Vote on behalf of the owner of the proposal, ie the agent that created it.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [OwnerVoteOptions](../interfaces/OwnerVoteOptions.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___
<a id="propose"></a>

###  propose

▸ **propose**(options: * [ProposeOptions](../interfaces/ProposeOptions.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionProposalResult](ArcTransactionProposalResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[propose](../interfaces/IIntVoteInterface.md#propose)*

*Defined in [wrappers/intVoteInterface.ts:86](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L86)*

Register a new proposal with the given parameters. Every proposal is given a unique ID which is a hash generated by calculating the keccak256 of a packing of an incremented counter and the address of the voting machine.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [ProposeOptions](../interfaces/ProposeOptions.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionProposalResult](ArcTransactionProposalResult.md)>

___
<a id="vote"></a>

###  vote

▸ **vote**(options: * [VoteOptions](../interfaces/VoteOptions.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[vote](../interfaces/IIntVoteInterface.md#vote)*

*Defined in [wrappers/intVoteInterface.ts:174](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L174)*

Vote on behalf of the current account or the given voter.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [VoteOptions](../interfaces/VoteOptions.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___
<a id="voteStatus"></a>

###  voteStatus

▸ **voteStatus**(options: *[VoteStatusOptions](../interfaces/VoteStatusOptions.md)*): `Promise`<`BigNumber`>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[voteStatus](../interfaces/IIntVoteInterface.md#voteStatus)*

*Defined in [wrappers/intVoteInterface.ts:266](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L266)*

Get the number of votes currently cast on the given choice.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options | [VoteStatusOptions](../interfaces/VoteStatusOptions.md) |   |

**Returns:** `Promise`<`BigNumber`>

___
<a id="voteWithSpecifiedAmounts"></a>

###  voteWithSpecifiedAmounts

▸ **voteWithSpecifiedAmounts**(options: * [VoteWithSpecifiedAmountsOptions](../interfaces/VoteWithSpecifiedAmountsOptions.md) & `TxGeneratingFunctionOptions`*): `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

*Implementation of [IIntVoteInterface](../interfaces/IIntVoteInterface.md).[voteWithSpecifiedAmounts](../interfaces/IIntVoteInterface.md#voteWithSpecifiedAmounts)*

*Defined in [wrappers/intVoteInterface.ts:194](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/intVoteInterface.ts#L194)*

Vote specified reputation amount on behalf of the current account or the given voter.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| options |  [VoteWithSpecifiedAmountsOptions](../interfaces/VoteWithSpecifiedAmountsOptions.md) & `TxGeneratingFunctionOptions`|   |

**Returns:** `Promise`<[ArcTransactionResult](ArcTransactionResult.md)>

___

