[API Reference](../README.md) > [ProposalGeneratorBase](../classes/ProposalGeneratorBase.md)

# Class: ProposalGeneratorBase

Methods for Arc universal schemes that can create proposals. Note that a contract that creates proposals doesn't necessary have to be a universal scheme, nor even a plain-old scheme. But all of the Arc proposal-generating schemes currently are currently universal schemes, so for the purposes of simplicity of organizating Arc.js and implementing these methods in one place, we define this as a `USchemeWrapperBase`.

## Hierarchy

↳  [USchemeWrapperBase](USchemeWrapperBase.md)

**↳ ProposalGeneratorBase**

↳  [ContributionRewardWrapper](ContributionRewardWrapper.md)

↳  [GlobalConstraintRegistrarWrapper](GlobalConstraintRegistrarWrapper.md)

↳  [SchemeRegistrarWrapper](SchemeRegistrarWrapper.md)

↳  [UpgradeSchemeWrapper](UpgradeSchemeWrapper.md)

↳  [VestingSchemeWrapper](VestingSchemeWrapper.md)

↳  [VoteInOrganizationSchemeWrapper](VoteInOrganizationSchemeWrapper.md)

## Implements

* [IContractWrapper](../interfaces/IContractWrapper.md)
* [ISchemeWrapper](../interfaces/ISchemeWrapper.md)

## Index

### Constructors

* [constructor](ProposalGeneratorBase.md#constructor)

### Properties

* [contract](ProposalGeneratorBase.md#contract)
* [factory](ProposalGeneratorBase.md#factory)
* [friendlyName](ProposalGeneratorBase.md#friendlyName)
* [name](ProposalGeneratorBase.md#name)

### Accessors

* [address](ProposalGeneratorBase.md#address)

### Methods

* [estimateGas](ProposalGeneratorBase.md#estimateGas)
* [getDefaultPermissions](ProposalGeneratorBase.md#getDefaultPermissions)
* [getParameters](ProposalGeneratorBase.md#getParameters)
* [getParametersArray](ProposalGeneratorBase.md#getParametersArray)
* [getParametersHash](ProposalGeneratorBase.md#getParametersHash)
* [getSchemeParameters](ProposalGeneratorBase.md#getSchemeParameters)
* [getSchemeParametersHash](ProposalGeneratorBase.md#getSchemeParametersHash)
* [getSchemePermissions](ProposalGeneratorBase.md#getSchemePermissions)
* [getVotingMachine](ProposalGeneratorBase.md#getVotingMachine)
* [getVotingMachineAddress](ProposalGeneratorBase.md#getVotingMachineAddress)
* [hydrateFromAt](ProposalGeneratorBase.md#hydrateFromAt)
* [hydrateFromNew](ProposalGeneratorBase.md#hydrateFromNew)
* [setParameters](ProposalGeneratorBase.md#setParameters)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new ProposalGeneratorBase**(solidityContract: *`any`*, web3EventService: *[Web3EventService](Web3EventService.md)*): [ProposalGeneratorBase](ProposalGeneratorBase.md)

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[constructor](ContractWrapperBase.md#constructor)*

*Defined in [proposalGeneratorBase.ts:17](https://github.com/daostack/arc.js/blob/6f704389/lib/proposalGeneratorBase.ts#L17)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| solidityContract | `any` |
| web3EventService | [Web3EventService](Web3EventService.md) |

**Returns:** [ProposalGeneratorBase](ProposalGeneratorBase.md)

___

## Properties

<a id="contract"></a>

###  contract

**● contract**: *`any`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[contract](../interfaces/ISchemeWrapper.md#contract)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[contract](ContractWrapperBase.md#contract)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

The underlying truffle contract object. Use this to access parts of the contract that aren't accessible via the wrapper.

___
<a id="factory"></a>

### `<Abstract>` factory

**● factory**: *[IContractWrapperFactory](../interfaces/IContractWrapperFactory.md)<`any`>*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[factory](../interfaces/ISchemeWrapper.md#factory)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[factory](ContractWrapperBase.md#factory)*

*Defined in [contractWrapperBase.ts:49](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L49)*

The wrapper factor class providing static methods `at(someAddress)`, `new()` and `deployed()`.

___
<a id="friendlyName"></a>

### `<Abstract>` friendlyName

**● friendlyName**: *`string`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[friendlyName](../interfaces/ISchemeWrapper.md#friendlyName)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[friendlyName](ContractWrapperBase.md#friendlyName)*

*Defined in [contractWrapperBase.ts:57](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L57)*

A more friendly name for the contract.

___
<a id="name"></a>

### `<Abstract>` name

**● name**: *`string`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[name](../interfaces/ISchemeWrapper.md#name)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[name](ContractWrapperBase.md#name)*

*Defined in [contractWrapperBase.ts:53](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L53)*

The name of the contract.

___

## Accessors

<a id="address"></a>

###  address

getaddress(): [Address](../#Address)

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[address](ContractWrapperBase.md#address)*

*Defined in [contractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L61)*

The address of the contract

**Returns:** [Address](../#Address)

___

## Methods

<a id="estimateGas"></a>

###  estimateGas

▸ **estimateGas**(func: *[ITruffleContractFunction](../interfaces/ITruffleContractFunction.md)*, params: *`Array`<`any`>*, web3Params?: *`any`*): `Promise`<`number`>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[estimateGas](ContractWrapperBase.md#estimateGas)*

*Defined in [contractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L140)*

Estimate conservatively the amount of gas required to execute the given function with the given parameters. Adds 21000 to the estimate computed by web3.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| func | [ITruffleContractFunction](../interfaces/ITruffleContractFunction.md) | - |  The function |
| params | `Array`<`any`> | - |  The parameters to send to the function |
| `Default value` web3Params | `any` |  {} |  The web3 parameters (like "from", for example). If it contains "gas" then that value is returned, effectively a no-op. |

**Returns:** `Promise`<`number`>

___
<a id="getDefaultPermissions"></a>

###  getDefaultPermissions

▸ **getDefaultPermissions**(): [SchemePermissions](../enums/SchemePermissions.md)

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[getDefaultPermissions](../interfaces/ISchemeWrapper.md#getDefaultPermissions)*

*Inherited from [SchemeWrapperBase](SchemeWrapperBase.md).[getDefaultPermissions](SchemeWrapperBase.md#getDefaultPermissions)*

*Defined in [schemeWrapperBase.ts:14](https://github.com/daostack/arc.js/blob/6f704389/lib/schemeWrapperBase.ts#L14)*

Minimum permissions required by the scheme

**Returns:** [SchemePermissions](../enums/SchemePermissions.md)

___
<a id="getParameters"></a>

### `<Abstract>` getParameters

▸ **getParameters**(paramsHash: *[Hash](../#Hash)*): `Promise`<`any`>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[getParameters](USchemeWrapperBase.md#getParameters)*

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[getParameters](ContractWrapperBase.md#getParameters)*

*Defined in [uSchemeWrapperBase.ts:22](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L22)*

Given a hash, returns the associated parameters as an object.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`any`>

___
<a id="getParametersArray"></a>

###  getParametersArray

▸ **getParametersArray**(paramsHash: *[Hash](../#Hash)*): `Promise`<`Array`<`any`>>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[getParametersArray](USchemeWrapperBase.md#getParametersArray)*

*Overrides [ContractWrapperBase](ContractWrapperBase.md).[getParametersArray](ContractWrapperBase.md#getParametersArray)*

*Defined in [uSchemeWrapperBase.ts:45](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L45)*

Given a hash, returns the associated parameters as an array, ordered by the order in which the parameters appear in the contract's Parameters struct.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`Array`<`any`>>

___
<a id="getParametersHash"></a>

### `<Abstract>` getParametersHash

▸ **getParametersHash**(params: *`any`*): `Promise`<[Hash](../#Hash)>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[getParametersHash](USchemeWrapperBase.md#getParametersHash)*

*Defined in [uSchemeWrapperBase.ts:24](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L24)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| params | `any` |

**Returns:** `Promise`<[Hash](../#Hash)>

___
<a id="getSchemeParameters"></a>

### `<Abstract>` getSchemeParameters

▸ **getSchemeParameters**(avatarAddress: *[Address](../#Address)*): `Promise`<`any`>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[getSchemeParameters](USchemeWrapperBase.md#getSchemeParameters)*

*Defined in [uSchemeWrapperBase.ts:28](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L28)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| avatarAddress | [Address](../#Address) |

**Returns:** `Promise`<`any`>

___
<a id="getSchemeParametersHash"></a>

###  getSchemeParametersHash

▸ **getSchemeParametersHash**(avatarAddress: *[Address](../#Address)*): `Promise`<[Hash](../#Hash)>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[getSchemeParametersHash](USchemeWrapperBase.md#getSchemeParametersHash)*

*Defined in [uSchemeWrapperBase.ts:34](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L34)*

Given an avatar address, returns the schemes parameters hash

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| avatarAddress | [Address](../#Address) |   |

**Returns:** `Promise`<[Hash](../#Hash)>

___
<a id="getSchemePermissions"></a>

###  getSchemePermissions

▸ **getSchemePermissions**(avatarAddress: *[Address](../#Address)*): `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[getSchemePermissions](../interfaces/ISchemeWrapper.md#getSchemePermissions)*

*Inherited from [SchemeWrapperBase](SchemeWrapperBase.md).[getSchemePermissions](SchemeWrapperBase.md#getSchemePermissions)*

*Defined in [schemeWrapperBase.ts:22](https://github.com/daostack/arc.js/blob/6f704389/lib/schemeWrapperBase.ts#L22)*

Returns the scheme permissions.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| avatarAddress | [Address](../#Address) |   |

**Returns:** `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

___
<a id="getVotingMachine"></a>

###  getVotingMachine

▸ **getVotingMachine**(avatarAddress: *[Address](../#Address)*): `Promise`<[IntVoteInterfaceWrapper](IntVoteInterfaceWrapper.md)>

*Defined in [proposalGeneratorBase.ts:37](https://github.com/daostack/arc.js/blob/6f704389/lib/proposalGeneratorBase.ts#L37)*

Return IntVoteInterfaceWrapper for this scheme as registered with the given avatar.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| avatarAddress | [Address](../#Address) |   |

**Returns:** `Promise`<[IntVoteInterfaceWrapper](IntVoteInterfaceWrapper.md)>

___
<a id="getVotingMachineAddress"></a>

###  getVotingMachineAddress

▸ **getVotingMachineAddress**(avatarAddress: *[Address](../#Address)*): `Promise`<[Address](../#Address)>

*Defined in [proposalGeneratorBase.ts:29](https://github.com/daostack/arc.js/blob/6f704389/lib/proposalGeneratorBase.ts#L29)*

Return the address of the voting machine for this scheme as registered with the given avatar.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| avatarAddress | [Address](../#Address) |   |

**Returns:** `Promise`<[Address](../#Address)>

___
<a id="hydrateFromAt"></a>

###  hydrateFromAt

▸ **hydrateFromAt**(address: *`string`*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[hydrateFromAt](../interfaces/ISchemeWrapper.md#hydrateFromAt)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromAt](ContractWrapperBase.md#hydrateFromAt)*

*Defined in [contractWrapperBase.ts:100](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L100)*

Initialize from a given address on the current network.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| address | `string` |  of the deployed contract |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this or undefined if not found

___
<a id="hydrateFromNew"></a>

###  hydrateFromNew

▸ **hydrateFromNew**(...rest: *`Array`<`any`>*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[hydrateFromNew](../interfaces/ISchemeWrapper.md#hydrateFromNew)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromNew](ContractWrapperBase.md#hydrateFromNew)*

*Defined in [contractWrapperBase.ts:81](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L81)*

Initialize from a newly-migrated instance. This will migrate a new instance of the contract to the net.

**Parameters:**

| Param | Type |
| ------ | ------ |
| `Rest` rest | `Array`<`any`> |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this

___
<a id="setParameters"></a>

### `<Abstract>` setParameters

▸ **setParameters**(params: *`any`*): `Promise`<[ArcTransactionDataResult](ArcTransactionDataResult.md)<[Hash](../#Hash)>>

*Inherited from [USchemeWrapperBase](USchemeWrapperBase.md).[setParameters](USchemeWrapperBase.md#setParameters)*

*Defined in [uSchemeWrapperBase.ts:26](https://github.com/daostack/arc.js/blob/6f704389/lib/uSchemeWrapperBase.ts#L26)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| params | `any` |

**Returns:** `Promise`<[ArcTransactionDataResult](ArcTransactionDataResult.md)<[Hash](../#Hash)>>

___

