[API Reference](../README.md) > [SchemeWrapperBase](../classes/SchemeWrapperBase.md)

# Class: SchemeWrapperBase

Abstract base class for all Arc scheme contract wrapper classes. A scheme is defined as an Arc contract that can be registered with and can thus interact with a DAO controller.

## Hierarchy

 [ContractWrapperBase](ContractWrapperBase.md)

**↳ SchemeWrapperBase**

↳  [Auction4ReputationWrapper](Auction4ReputationWrapper.md)

↳  [USchemeWrapperBase](USchemeWrapperBase.md)

↳  [Locking4ReputationWrapper](Locking4ReputationWrapper.md)

↳  [FixedReputationAllocationWrapper](FixedReputationAllocationWrapper.md)

## Implements

* [IContractWrapper](../interfaces/IContractWrapper.md)
* [ISchemeWrapper](../interfaces/ISchemeWrapper.md)

## Index

### Constructors

* [constructor](SchemeWrapperBase.md#constructor)

### Properties

* [contract](SchemeWrapperBase.md#contract)
* [factory](SchemeWrapperBase.md#factory)
* [friendlyName](SchemeWrapperBase.md#friendlyName)
* [name](SchemeWrapperBase.md#name)

### Accessors

* [address](SchemeWrapperBase.md#address)

### Methods

* [estimateGas](SchemeWrapperBase.md#estimateGas)
* [getDefaultPermissions](SchemeWrapperBase.md#getDefaultPermissions)
* [getParameters](SchemeWrapperBase.md#getParameters)
* [getParametersArray](SchemeWrapperBase.md#getParametersArray)
* [getSchemePermissions](SchemeWrapperBase.md#getSchemePermissions)
* [hydrateFromAt](SchemeWrapperBase.md#hydrateFromAt)
* [hydrateFromNew](SchemeWrapperBase.md#hydrateFromNew)

---

## Constructors

<a id="constructor"></a>

###  constructor

⊕ **new SchemeWrapperBase**(solidityContract: *`any`*, web3EventService: *[Web3EventService](Web3EventService.md)*): [SchemeWrapperBase](SchemeWrapperBase.md)

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[constructor](ContractWrapperBase.md#constructor)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

ContractWrapperFactory constructs this

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| solidityContract | `any` |  The json contract truffle artifact |
| web3EventService | [Web3EventService](Web3EventService.md) |   |

**Returns:** [SchemeWrapperBase](SchemeWrapperBase.md)

___

## Properties

<a id="contract"></a>

###  contract

**● contract**: *`any`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[contract](../interfaces/ISchemeWrapper.md#contract)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[contract](ContractWrapperBase.md#contract)*

*Defined in [contractWrapperBase.ts:66](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L66)*

The underlying truffle contract object. Use this to access parts of the contract that aren't accessible via the wrapper.

___
<a id="factory"></a>

### `<Abstract>` factory

**● factory**: *[IContractWrapperFactory](../interfaces/IContractWrapperFactory.md)<`any`>*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[factory](../interfaces/ISchemeWrapper.md#factory)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[factory](ContractWrapperBase.md#factory)*

*Defined in [contractWrapperBase.ts:49](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L49)*

The wrapper factor class providing static methods `at(someAddress)`, `new()` and `deployed()`.

___
<a id="friendlyName"></a>

### `<Abstract>` friendlyName

**● friendlyName**: *`string`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[friendlyName](../interfaces/ISchemeWrapper.md#friendlyName)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[friendlyName](ContractWrapperBase.md#friendlyName)*

*Defined in [contractWrapperBase.ts:57](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L57)*

A more friendly name for the contract.

___
<a id="name"></a>

### `<Abstract>` name

**● name**: *`string`*

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[name](../interfaces/ISchemeWrapper.md#name)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[name](ContractWrapperBase.md#name)*

*Defined in [contractWrapperBase.ts:53](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L53)*

The name of the contract.

___

## Accessors

<a id="address"></a>

###  address

getaddress(): [Address](../#Address)

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[address](ContractWrapperBase.md#address)*

*Defined in [contractWrapperBase.ts:61](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L61)*

The address of the contract

**Returns:** [Address](../#Address)

___

## Methods

<a id="estimateGas"></a>

###  estimateGas

▸ **estimateGas**(func: *[ITruffleContractFunction](../interfaces/ITruffleContractFunction.md)*, params: *`Array`<`any`>*, web3Params?: *`any`*): `Promise`<`number`>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[estimateGas](ContractWrapperBase.md#estimateGas)*

*Defined in [contractWrapperBase.ts:140](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L140)*

Estimate conservatively the amount of gas required to execute the given function with the given parameters. Adds 21000 to the estimate computed by web3.

**Parameters:**

| Param | Type | Default value | Description |
| ------ | ------ | ------ | ------ |
| func | [ITruffleContractFunction](../interfaces/ITruffleContractFunction.md) | - |  The function |
| params | `Array`<`any`> | - |  The parameters to send to the function |
| `Default value` web3Params | `any` |  {} |  The web3 parameters (like "from", for example). If it contains "gas" then that value is returned, effectively a no-op. |

**Returns:** `Promise`<`number`>

___
<a id="getDefaultPermissions"></a>

###  getDefaultPermissions

▸ **getDefaultPermissions**(): [SchemePermissions](../enums/SchemePermissions.md)

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[getDefaultPermissions](../interfaces/ISchemeWrapper.md#getDefaultPermissions)*

*Defined in [schemeWrapperBase.ts:14](https://github.com/daostack/arc.js/blob/6f704389/lib/schemeWrapperBase.ts#L14)*

Minimum permissions required by the scheme

**Returns:** [SchemePermissions](../enums/SchemePermissions.md)

___
<a id="getParameters"></a>

###  getParameters

▸ **getParameters**(paramsHash: *[Hash](../#Hash)*): `Promise`<`any`>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[getParameters](ContractWrapperBase.md#getParameters)*

*Defined in [contractWrapperBase.ts:118](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L118)*

Given a hash, returns the associated parameters as an object.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`any`>

___
<a id="getParametersArray"></a>

###  getParametersArray

▸ **getParametersArray**(paramsHash: *[Hash](../#Hash)*): `Promise`<`Array`<`any`>>

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[getParametersArray](ContractWrapperBase.md#getParametersArray)*

*Defined in [contractWrapperBase.ts:127](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L127)*

Given a hash, returns the associated parameters as an array, ordered by the order in which the parameters appear in the contract's Parameters struct.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| paramsHash | [Hash](../#Hash) |   |

**Returns:** `Promise`<`Array`<`any`>>

___
<a id="getSchemePermissions"></a>

###  getSchemePermissions

▸ **getSchemePermissions**(avatarAddress: *[Address](../#Address)*): `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[getSchemePermissions](../interfaces/ISchemeWrapper.md#getSchemePermissions)*

*Defined in [schemeWrapperBase.ts:22](https://github.com/daostack/arc.js/blob/6f704389/lib/schemeWrapperBase.ts#L22)*

Returns the scheme permissions.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| avatarAddress | [Address](../#Address) |   |

**Returns:** `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

___
<a id="hydrateFromAt"></a>

###  hydrateFromAt

▸ **hydrateFromAt**(address: *`string`*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[hydrateFromAt](../interfaces/ISchemeWrapper.md#hydrateFromAt)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromAt](ContractWrapperBase.md#hydrateFromAt)*

*Defined in [contractWrapperBase.ts:100](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L100)*

Initialize from a given address on the current network.

**Parameters:**

| Param | Type | Description |
| ------ | ------ | ------ |
| address | `string` |  of the deployed contract |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this or undefined if not found

___
<a id="hydrateFromNew"></a>

###  hydrateFromNew

▸ **hydrateFromNew**(...rest: *`Array`<`any`>*): `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>

*Implementation of [ISchemeWrapper](../interfaces/ISchemeWrapper.md).[hydrateFromNew](../interfaces/ISchemeWrapper.md#hydrateFromNew)*

*Inherited from [ContractWrapperBase](ContractWrapperBase.md).[hydrateFromNew](ContractWrapperBase.md#hydrateFromNew)*

*Defined in [contractWrapperBase.ts:81](https://github.com/daostack/arc.js/blob/6f704389/lib/contractWrapperBase.ts#L81)*

Initialize from a newly-migrated instance. This will migrate a new instance of the contract to the net.

**Parameters:**

| Param | Type |
| ------ | ------ |
| `Rest` rest | `Array`<`any`> |

**Returns:** `Promise`<[IContractWrapper](../interfaces/IContractWrapper.md)>
this

___

