[API Reference](../README.md) > [GenesisProtocolParams](../interfaces/GenesisProtocolParams.md)

# Interface: GenesisProtocolParams

## Hierarchy

**GenesisProtocolParams**

## Index

### Properties

* [boostedVotePeriodLimit](GenesisProtocolParams.md#boostedVotePeriodLimit)
* [daoBountyConst](GenesisProtocolParams.md#daoBountyConst)
* [daoBountyLimit](GenesisProtocolParams.md#daoBountyLimit)
* [minimumStakingFee](GenesisProtocolParams.md#minimumStakingFee)
* [preBoostedVotePeriodLimit](GenesisProtocolParams.md#preBoostedVotePeriodLimit)
* [preBoostedVoteRequiredPercentage](GenesisProtocolParams.md#preBoostedVoteRequiredPercentage)
* [proposingRepRewardConstA](GenesisProtocolParams.md#proposingRepRewardConstA)
* [proposingRepRewardConstB](GenesisProtocolParams.md#proposingRepRewardConstB)
* [quietEndingPeriod](GenesisProtocolParams.md#quietEndingPeriod)
* [stakerFeeRatioForVoters](GenesisProtocolParams.md#stakerFeeRatioForVoters)
* [thresholdConstA](GenesisProtocolParams.md#thresholdConstA)
* [thresholdConstB](GenesisProtocolParams.md#thresholdConstB)
* [voteOnBehalf](GenesisProtocolParams.md#voteOnBehalf)
* [votersGainRepRatioFromLostRep](GenesisProtocolParams.md#votersGainRepRatioFromLostRep)
* [votersReputationLossRatio](GenesisProtocolParams.md#votersReputationLossRatio)

---

## Properties

<a id="boostedVotePeriodLimit"></a>

###  boostedVotePeriodLimit

**● boostedVotePeriodLimit**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1100](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1100)*

The time limit in seconds for a proposal to be in the boosted phase, inclusive of the quietEndingPeriod, in seconds. Default is 259200 (three days).

___
<a id="daoBountyConst"></a>

###  daoBountyConst

**● daoBountyConst**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1106](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1106)*

Multiple of a winning stake to be rewarded as bounty. Must be greater than stakerFeeRatioForVoters and less than 2\*stakerFeeRatioForVoters. Default is 75.

___
<a id="daoBountyLimit"></a>

###  daoBountyLimit

**● daoBountyLimit**: * `BigNumber` &#124; `string`
*

*Defined in [wrappers/genesisProtocol.ts:1111](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1111)*

Upper bound on the total bounty amount on a proposal. Default is 100, converted to Wei.

___
<a id="minimumStakingFee"></a>

###  minimumStakingFee

**● minimumStakingFee**: * `BigNumber` &#124; `string`
*

*Defined in [wrappers/genesisProtocol.ts:1117](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1117)*

A floor on the staking fee which is normally computed using [GenesisProtocolParams.stakerFeeRatioForVoters](GenesisProtocolParams.md#stakerFeeRatioForVoters), in Wei. Default is 0.

___
<a id="preBoostedVotePeriodLimit"></a>

###  preBoostedVotePeriodLimit

**● preBoostedVotePeriodLimit**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1125](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1125)*

The time limit in seconds that a proposal can be in the preBoosted phase before it will be automatically closed, in seconds, with a winning vote of NO, regardless of the actual value of the winning vote at the time expiration. Note an attempt must be made to execute before the proposal state will actually change. Default is 1814400 (three weeks).

___
<a id="preBoostedVoteRequiredPercentage"></a>

###  preBoostedVoteRequiredPercentage

**● preBoostedVoteRequiredPercentage**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1134](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1134)*

The percent of the DAO's total supply of reputation that, when exceeded by the amount of reputation behind a vote (yes or no), will result in the immediate execution of the proposal, during either the preboosted or boosted phases. Must be greater than zero and less than or equal to 100. Default is 50.

___
<a id="proposingRepRewardConstA"></a>

###  proposingRepRewardConstA

**● proposingRepRewardConstA**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1140](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1140)*

Constant A in the calculation of the proposer's reputation reward. Must be between 0 and 100000000. Default is 5.

___
<a id="proposingRepRewardConstB"></a>

###  proposingRepRewardConstB

**● proposingRepRewardConstB**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1146](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1146)*

Constant B in the calculation of the proposer's reputation reward. Must be between 0 and 100000000. Default is 5.

___
<a id="quietEndingPeriod"></a>

###  quietEndingPeriod

**● quietEndingPeriod**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1156](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1156)*

The duration, in seconds, at the end of the boosted phase during which any vote that changes the outcome of a proposal will cause the boosted phase to be extended by the amount of the quietEndingPeriod. If the quietEndingPeriod expires then the proposal expires and may be executed. It is a moving window: If the winning vote switches during the quietEndingPeriod then it restarts at the point in time when the vote switched, thus extending the boosted period. Default is 86400 (one day).

___
<a id="stakerFeeRatioForVoters"></a>

###  stakerFeeRatioForVoters

**● stakerFeeRatioForVoters**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1164](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1164)*

For executed proposals, the percentage of staked tokens that is rewarded to all voters, regardless of the vote outcome, the staked vote outcome, or how the voter voted. Voters share this amount in proportion to the amount of reputation they voted. Must be between 0 and 100. Default is 50.

___
<a id="thresholdConstA"></a>

###  thresholdConstA

**● thresholdConstA**: * `BigNumber` &#124; `string`
*

*Defined in [wrappers/genesisProtocol.ts:1172](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1172)*

Constant A in the threshold calculation, in Wei. See \[\[GenesisProtocolWrapper.getThreshold\]\]. If the difference between Yes and No votes exceeds the threshold, then the proposal may be boosted. Must be between 0 and 100000000 (converted to Wei). Default is 7, converted to Wei.

___
<a id="thresholdConstB"></a>

###  thresholdConstB

**● thresholdConstB**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1180](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1180)*

Constant B in the threshold calculation. See \[\[GenesisProtocolWrapper.getThreshold\]\]. If the difference between Yes and No votes exceeds the threshold, then the proposal may be boosted. Must be greater than zero and less than or equal to 100000000. Default is 3.

___
<a id="voteOnBehalf"></a>

### `<Optional>` voteOnBehalf

**● voteOnBehalf**: *[Address](../#Address)*

*Defined in [wrappers/genesisProtocol.ts:1184](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1184)*

optional, to always vote on behalf of the given account. Otherwise is `msg.sender`.

___
<a id="votersGainRepRatioFromLostRep"></a>

###  votersGainRepRatioFromLostRep

**● votersGainRepRatioFromLostRep**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1191](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1191)*

The percentage of losing pre-boosted voters' lost reputation (see votersReputationLossRatio) rewarded to winning pre-boosted voters. Must be between 0 and 100. Default is 80.

___
<a id="votersReputationLossRatio"></a>

###  votersReputationLossRatio

**● votersReputationLossRatio**: *`number`*

*Defined in [wrappers/genesisProtocol.ts:1197](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/genesisProtocol.ts#L1197)*

The percentage of reputation deducted from losing pre-boosted voters. Must be between 0 and 100. Default is 1.

___

