[API Reference](../README.md) > [ISchemeWrapper](../interfaces/ISchemeWrapper.md)

# Interface: ISchemeWrapper

The minimum requirements for a scheme that can be registered with a DAO/controller.

## Hierarchy

 [IContractWrapper](IContractWrapper.md)

**↳ ISchemeWrapper**

↳  [IUniversalSchemeWrapper](IUniversalSchemeWrapper.md)

## Implemented by

* [Auction4ReputationWrapper](../classes/Auction4ReputationWrapper.md)
* [ContributionRewardWrapper](../classes/ContributionRewardWrapper.md)
* [ExternalLocking4ReputationWrapper](../classes/ExternalLocking4ReputationWrapper.md)
* [FixedReputationAllocationWrapper](../classes/FixedReputationAllocationWrapper.md)
* [GlobalConstraintRegistrarWrapper](../classes/GlobalConstraintRegistrarWrapper.md)
* [Locking4ReputationWrapper](../classes/Locking4ReputationWrapper.md)
* [LockingEth4ReputationWrapper](../classes/LockingEth4ReputationWrapper.md)
* [LockingToken4ReputationWrapper](../classes/LockingToken4ReputationWrapper.md)
* [ProposalGeneratorBase](../classes/ProposalGeneratorBase.md)
* [SchemeRegistrarWrapper](../classes/SchemeRegistrarWrapper.md)
* [SchemeWrapperBase](../classes/SchemeWrapperBase.md)
* [USchemeWrapperBase](../classes/USchemeWrapperBase.md)
* [UpgradeSchemeWrapper](../classes/UpgradeSchemeWrapper.md)
* [VestingSchemeWrapper](../classes/VestingSchemeWrapper.md)
* [VoteInOrganizationSchemeWrapper](../classes/VoteInOrganizationSchemeWrapper.md)

## Index

### Properties

* [address](ISchemeWrapper.md#address)
* [contract](ISchemeWrapper.md#contract)
* [factory](ISchemeWrapper.md#factory)
* [friendlyName](ISchemeWrapper.md#friendlyName)
* [name](ISchemeWrapper.md#name)

### Methods

* [getDefaultPermissions](ISchemeWrapper.md#getDefaultPermissions)
* [getSchemePermissions](ISchemeWrapper.md#getSchemePermissions)
* [hydrateFromAt](ISchemeWrapper.md#hydrateFromAt)
* [hydrateFromNew](ISchemeWrapper.md#hydrateFromNew)

---

## Properties

<a id="address"></a>

###  address

**● address**: *[Address](../#Address)*

*Inherited from [IContractWrapper](IContractWrapper.md).[address](IContractWrapper.md#address)*

*Defined in [iContractWrapperBase.ts:13](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L13)*

___
<a id="contract"></a>

###  contract

**● contract**: *`any`*

*Inherited from [IContractWrapper](IContractWrapper.md).[contract](IContractWrapper.md#contract)*

*Defined in [iContractWrapperBase.ts:14](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L14)*

___
<a id="factory"></a>

###  factory

**● factory**: *[IContractWrapperFactory](IContractWrapperFactory.md)<`any`>*

*Inherited from [IContractWrapper](IContractWrapper.md).[factory](IContractWrapper.md#factory)*

*Defined in [iContractWrapperBase.ts:10](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L10)*

___
<a id="friendlyName"></a>

###  friendlyName

**● friendlyName**: *`string`*

*Inherited from [IContractWrapper](IContractWrapper.md).[friendlyName](IContractWrapper.md#friendlyName)*

*Defined in [iContractWrapperBase.ts:12](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L12)*

___
<a id="name"></a>

###  name

**● name**: *`string`*

*Inherited from [IContractWrapper](IContractWrapper.md).[name](IContractWrapper.md#name)*

*Defined in [iContractWrapperBase.ts:11](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L11)*

___

## Methods

<a id="getDefaultPermissions"></a>

###  getDefaultPermissions

▸ **getDefaultPermissions**(): [SchemePermissions](../enums/SchemePermissions.md)

*Defined in [iContractWrapperBase.ts:24](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L24)*

**Returns:** [SchemePermissions](../enums/SchemePermissions.md)

___
<a id="getSchemePermissions"></a>

###  getSchemePermissions

▸ **getSchemePermissions**(avatarAddress: *[Address](../#Address)*): `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

*Defined in [iContractWrapperBase.ts:23](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L23)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| avatarAddress | [Address](../#Address) |

**Returns:** `Promise`<[SchemePermissions](../enums/SchemePermissions.md)>

___
<a id="hydrateFromAt"></a>

###  hydrateFromAt

▸ **hydrateFromAt**(address: *`string`*): `Promise`<`any`>

*Inherited from [IContractWrapper](IContractWrapper.md).[hydrateFromAt](IContractWrapper.md#hydrateFromAt)*

*Defined in [iContractWrapperBase.ts:16](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L16)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| address | `string` |

**Returns:** `Promise`<`any`>

___
<a id="hydrateFromNew"></a>

###  hydrateFromNew

▸ **hydrateFromNew**(...rest: *`Array`<`any`>*): `Promise`<`any`>

*Inherited from [IContractWrapper](IContractWrapper.md).[hydrateFromNew](IContractWrapper.md#hydrateFromNew)*

*Defined in [iContractWrapperBase.ts:15](https://github.com/daostack/arc.js/blob/6f704389/lib/iContractWrapperBase.ts#L15)*

**Parameters:**

| Param | Type |
| ------ | ------ |
| `Rest` rest | `Array`<`any`> |

**Returns:** `Promise`<`any`>

___

