[API Reference](../README.md) > [SchemeConfig](../interfaces/SchemeConfig.md)

# Interface: SchemeConfig

Configuration of an Arc scheme that you want to automatically register with a new DAO.

## Hierarchy

**SchemeConfig**

## Indexable

\[x: `string`\]:&nbsp;`any`
You can add other scheme parameters here. For example, ContributionReward requires orgNativeTokenFee. SchemeRegistrar has voteRemoveParametersHash.

## Index

### Properties

* [address](SchemeConfig.md#address)
* [name](SchemeConfig.md#name)
* [parametersHash](SchemeConfig.md#parametersHash)
* [permissions](SchemeConfig.md#permissions)
* [votingMachineParams](SchemeConfig.md#votingMachineParams)

---

## Properties

<a id="address"></a>

### `<Optional>` address

**● address**: *`string`*

*Defined in [wrappers/daoCreator.ts:591](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/daoCreator.ts#L591)*

Scheme address if you don't want to use the scheme deployed in this release of Arc.js, or if it is a non-Arc scheme.

___
<a id="name"></a>

### `<Optional>` name

**● name**: *`string`*

*Defined in [wrappers/daoCreator.ts:586](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/daoCreator.ts#L586)*

The name of the Arc scheme. Omit this only if it is a non-Arc scheme.

___
<a id="parametersHash"></a>

### `<Optional>` parametersHash

**● parametersHash**: *[Hash](../#Hash)*

*Defined in [wrappers/daoCreator.ts:621](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/daoCreator.ts#L621)*

Optional scheme parameters hash for schemes, particularly for schemes that are not wrapped in Arc.js. If this is supplied, then any other parameters (either in x or votingMachineParams) are ignored.

___
<a id="permissions"></a>

### `<Optional>` permissions

**● permissions**: *[SchemePermissions](../enums/SchemePermissions.md)*

*Defined in [wrappers/daoCreator.ts:598](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/daoCreator.ts#L598)*

Extra permissions on the scheme. The minimum permissions for the scheme will be enforced (or'd with anything you supply). See ContractWrapperBase.getDefaultPermissions for what this string should look like.

___
<a id="votingMachineParams"></a>

### `<Optional>` votingMachineParams

**● votingMachineParams**: *[NewDaoVotingMachineConfig](NewDaoVotingMachineConfig.md)*

*Defined in [wrappers/daoCreator.ts:610](https://github.com/daostack/arc.js/blob/6f704389/lib/wrappers/daoCreator.ts#L610)*

Optional votingMachine parameters if you have not supplied them in ForgeOrgConfig or want to override them. Note it costs more gas to add them here.

New schemes will be created with these voting machine parameters. This is only relevant to schemes that can create proposals upon which there can be a vote. Other schemes will ignore these parameters.

Defaults are those of whatever voting machine is the default for DaoCreator. The default default VotingMachine is AbsoluteVote.

___

